VoiceReplyTextEvent class

A chunk of the LLM's streamed text reply (token granularity in v1).

Inheritance

Constructors

VoiceReplyTextEvent(String chunk)
const

Properties

chunk String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited