VoiceTranscriptEvent class

Recognized user speech. v1 emits exactly one with isFinal = true.

Inheritance

Constructors

VoiceTranscriptEvent(String text, {required bool isFinal})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isFinal bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited